% Letterclass for the Economics faculty of the University of Gttingen
% Written by Felix Kaminsky
% Created Feb. 27th 2009

\NeedsTeXFormat{LaTeX2e} \ProvidesClass{gauglttr}
\RequirePackage{ifthen}
\RequirePackage{graphics}
\RequirePackage{graphicx}
\RequirePackage{tabularx}
\RequirePackage[colorlinks=true,
        linkcolor=black,
        citecolor=black,
        filecolor=black,
        pagecolor=black,
        urlcolor=black,
        bookmarks=true,
        bookmarksopen=true,
        bookmarksopenlevel=3,
        plainpages=false,
        pdfpagelabels=true]{hyperref}


%-------------Schalter-----------------------------------------------------
 %-german-
\newboolean{@german}	\setboolean{@german}{false}
\DeclareOption{german}{\setboolean{@german}{true}}
\DeclareOption{english}{\setboolean{@german}{false}}
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{letter}}
\ExecuteOptions{english}	
 %-arial-
 \newboolean{@arial} \setboolean{@arial}{false}
 \DeclareOption{arial}{\setboolean{@arial}{true}}
 \def\@optptsize{10pt}
 \DeclareOption{10pt}{\def\@optptsize{10pt}}
\DeclareOption{11pt}{\def\@optptsize{11pt}}
\DeclareOption{12pt}{\def\@optptsize{12pt}}
 \ProcessOptions

%-------------Lade Basis-Klasse letter--------------------------------- 
\LoadClass[a4paper,\@optptsize]{letter}
%-------------Text in ARIAL mit XeTeX-----------------------------------
\ifthenelse{\boolean{@arial}}
{\RequirePackage{fontspec} 
\fontspec{Arial}\fontsize{8pt}{10pt}\selectfont \setmainfont{Arial}
\newcommand{\fontarial}{\fontspec{Arial}}}{\renewcommand{\rmdefault}{cmss} \newcommand{\fontarial}{\sffamily}}
%-------------Fester Inhalt fr English und Deutsch------------------------
\newcommand{\lettergerman}{
\def\ycom{Ihre Nachricht vom}
\def\ocom{Unsere Nachricht vom}
\def\yref{Ihr Zeichen}
\def\oref{Unser Zeichen}
\ifthenelse{\boolean{@arial}}
{\def\mfg{Mit freundlichen Grüßen\par}}{\def\mfg{Mit freundlichen Gr\"u\ss{}en\par}}
\def\pho{Tel. }
\def\eco@headlogo{\parbox{\textwidth}{
\includegraphics[width=170mm]{head-de}}
}
}
\newcommand{\letterenglish}{
\def\ycom{Your communication of}
\def\ocom{Our communication of}
\def\yref{Your ref.}
\def\oref{Our ref.}
\def\mfg{Sincerely\par}
\def\pho{Phone }
\def\eco@headlogo{\parbox{\textwidth}{
\includegraphics[width=170mm]{head-en}}
}
}
\ifthenelse{\boolean{@german}}
	{\RequirePackage{german}\lettergerman}{\letterenglish}
%-----------------Variablen--------------------------------------------
 %---undefine variables of letter.cls---

\let\name\@undefined		\let\fromname\@undefined
\let\address\@undefined		\let\fromaddress\@undefined
\let\location\@undefined	\let\fromlocation\@undefined
\let\telephone\@undefined	\let\telephonenum\@undefined

 %---new---
  %-head-logo-
  \newcommand{\headlogo}[1]{\def\eco@headlogo{\parbox{\textwidth}{\includegraphics[width=170mm]{#1}}}}
  %-to-
\newcommand{\toname}[1]{\def\eco@toname{#1}}
\newcommand{\toaddress}[1]{\def\eco@toaddress{#1}}
  %-from-
\newcommand{\fromname}[1]{\def\eco@fromname{#1}}
\newcommand{\fromtitle}[1]{\def\eco@fromtitle{#1}}
\newcommand{\frommail}[1]{\def\eco@frommail{\href{mailto:#1}{#1}}}
\newcommand{\fromlocation}[1]{\def\eco@fromlocation{#1}}
\newcommand{\fromdate}[1]{\def\eco@fromdate{#1}}
  %-personal-
\newcommand{\persphone}[1]{\def\eco@persphone{#1}}
\newcommand{\persfax}[1]{\def\eco@persfax{#1}}
  %-chair-
\newcommand{\chairphone}[1]{\def\eco@chairphone{#1}}
\newcommand{\chairfax}[1]{\def\eco@chairfax{#1}}
\newcommand{\chairmail}[1]{\def\eco@chairmail{\href{mailto:#1}{#1}}}
\newcommand{\chairwpage}[1]{\def\eco@chairwpage{\href{http://#1}{#1}}}
  %-referal-
\newcommand{\yourcom}[1]{\def\eco@yourcom{#1}}
\newcommand{\ourcom}[1]{\def\eco@ourcom{#1}}
\newcommand{\yourref}[1]{\def\eco@yourref{#1}}
\newcommand{\ourref}[1]{\def\eco@ourref{#1}}
  %-subject-
\newcommand{\subject}[1]{\def\eco@subject{\textbf{#1}\par}}

  %-catch not set variables-
\toname{}
\toaddress{}
\fromname{}
\fromtitle{}
\frommail{}
\fromlocation{}
\fromdate{}
\persphone{}
\persfax{}
\chairphone{}
\chairfax{}
\chairmail{}
\chairwpage{}
\yourcom{}
\ourcom{}
\yourref{}
\ourref{}
\subject{}
%-----------------Lngen-/Breitendefinitionen--------------------------

\setlength{\hoffset}{-1in}		\setlength{\voffset}{-1in}
\setlength{\topmargin}{17mm}	\setlength{\marginparwidth}{20mm}
\setlength{\oddsidemargin}{20mm}
\setlength{\evensidemargin}{20mm}
\setlength{\textwidth}{170mm}	
\setlength{\textheight}{170mm}
\setlength{\headheight}{30pt}	\setlength{\headsep}{30pt}
\setlength{\footskip}{10mm}

\newdimen\leftfield				\setlength{\leftfield}{84mm}
\newdimen\rightfield			\setlength{\rightfield}{85mm}

%------ Erste Seite ----------
\def\ps@firstpage{
\setlength{\headsep}{230pt}
\def\@oddhead{\parbox{\textwidth}{
\eco@headlogo\\
\parbox{\textwidth}{\vspace{8mm}
{\fontsize{7pt}{1pt}\fontarial
\eco@fromname\ $\cdot$ Platz der G\"ottinger Sieben 3 $\cdot$ 37073 G\"ottingen\ifthenelse{\boolean{@german}}{}{ $\cdot$ Germany}}
}\linebreak
\parbox[c][30mm][c]{\textwidth}{\vspace{5mm}
\parbox[t!]{\leftfield}{\fontarial
		\ifx\eco@toname\@empty{\hfill}\else{\eco@toname\\}\fi
		\ifx\eco@toaddress\@empty{}\else{\eco@toaddress}\fi}
\parbox[t!]{\rightfield}{\begin{flushright}
  \ifx\eco@fromname\@empty{}\else{\textbf{\eco@fromname}\\}\fi
{\fontsize{8}{10}\fontarial
\ifx\eco@fromtitle\@empty{\vspace{3mm}}\else{\eco@fromtitle\\}\fi
\ifx\eco@frommail\@empty{}\else{\vspace{3mm}\eco@frommail\\}\fi
  \ifx\eco@persphone\@empty{}\else{\eco@persphone\\}\fi
  \ifx\eco@persfax\@empty{}\else{\eco@persfax}\fi
  }
\end{flushright}}\vfill
}
\begin{flushright}
 \ifx\eco@fromlocation\@empty{}\else{\eco@fromlocation, }\fi\ifx\eco@fromlocation\@empty{}\else{\eco@fromdate}\fi
\end{flushright}
\vspace{3mm}
\ifx\eco@yourcom\@empty{}
\else{
\parbox[c][13mm][t]{\textwidth}{
{\fontsize{8pt}{10pt}\fontarial
\hspace{-6.5pt}\begin{tabularx}{1.025\textwidth}{l X l X l X l}
  \ycom && \ocom && \yref && \oref\\
  \eco@yourcom && \eco@ourcom && \eco@yourref && \eco@ourref
\end{tabularx}
}
}
}
\fi
\vspace{9mm}
\eco@subject
}
}
 %--- Definition 1. Fuzeile---
	\def\@oddfoot{
	{\fontsize{8pt}{10pt}\fontarial
	\hspace{-8pt}\begin{tabularx}{1.025\textwidth}{l X l X r}
	  Platz der G\"ottinger Sieben 3 && \pho +49 (0)551 / 39-\ifx\eco@chairphone\@empty{}\else{\eco@chairphone}\fi && \ifx\eco@chairmail\@empty{}\else{\eco@chairmail}\fi \\
	  37073 G\"ottingen && Fax +49 (0)551 / 39-\ifx\eco@chairfax\@empty{}\else{\eco@chairfax}\fi  && \ifx\eco@chairwpage\@empty{}\else{\eco@chairwpage}\fi
	  \end{tabularx}
	  }
	} 
	\def\@evenhead{} \def\@evenfoot{}
}

%----------Alle weiteren Seiten-----------
\def\ps@headings{\def\@oddhead{
	\eco@headlogo\\
	}
	\let\@evenhead=\@oddhead
 %--- Weitere Fuzeilen---
	\def\@oddfoot{
	{\fontsize{8pt}{10pt}\fontarial
	\hspace{-8pt}\begin{tabularx}{1.025\textwidth}{l X l X r}
	  Platz der G\"ottinger Sieben 3 && \pho +49 (0)551 / 39-\ifx\eco@chairphone\@empty{}\else{\eco@chairphone}\fi && \ifx\eco@chairmail\@empty{}\else{\eco@chairmail}\fi \\
		37073 G\"ottingen && Fax +49 (0)551 / 39-\ifx\eco@chairfax\@empty{}\else{\eco@chairfax}\fi  && \ifx\eco@chairwpage\@empty{}\else{\eco@chairwpage}\fi
	  \end{tabularx}
	  }
	}
	\let\@evenfoot=\@oddfoot 
}
  \ps@headings

%-----Opening------------------
\def\opening#1{\setlength{\textheight}{240mm}\thispagestyle{firstpage}
\vspace{\parskip}#1\par}


%-------Closing----------------
\def\closing#1{\par\vspace{2\parskip} #1}
